@@ -1,5 +1,5 @@
 var a00875 =
 [
     [ "RefinerSurfaceFactoryBase", "a00916.html", "a00916" ],
-    [ "RefinerSurfaceFactory< CACHE_TYPE >", "a00920.html", "a00920" ]
+    [ "RefinerSurfaceFactory&lt; CACHE_TYPE &gt;", "a00920.html", "a00920" ]
 ];
\ No newline at end of file
